]> git.tuebingen.mpg.de Git - paraslash.git/blobdiff - server.c
dbtool -> audio file selector renaming
[paraslash.git] / server.c
index 41f1558d44fac653ef3c4d323b725e3fc8ef9cc8..e78b73f4fd222f2f9029b6658f671e9b6906c901 100644 (file)
--- a/server.c
+++ b/server.c
@@ -47,11 +47,11 @@ INIT_SERVER_ERRLISTS;
 /** shut down non-authorized connections after that many seconds */
 #define ALARM_TIMEOUT 10
 
-/* these are exported to afs/command/dbtool */
+/* these are exported to afs.c. command.c and to all selectors */
 struct misc_meta_data *mmd;
 /** the configuration of para_server
  *
* It also contains the options for all database tools and all supported
  * senders.
 */
 struct gengetopt_args_info conf;
@@ -60,7 +60,7 @@ extern void http_send_init(struct sender *);
 extern void ortp_send_init(struct sender *);
 extern struct audio_format afl[];
 
-/** the list of supported database tools */
+/** the list of supported audio file selectors */
 struct dbtool dblist[] = {
        {
                .name = "random",
@@ -286,7 +286,7 @@ static void init_dbtool(void)
        for (i = 0; dblist[i].name; i++) {
                if (strcmp(dblist[i].name, conf.selector_arg))
                        continue;
-               PARA_NOTICE_LOG("initializing %s database tool\n",
+               PARA_NOTICE_LOG("initializing %s audio file selector\n",
                        dblist[i].name);
                ret = dblist[i].init(&dblist[i]);
                if (ret < 0) {
@@ -296,7 +296,7 @@ static void init_dbtool(void)
                mmd->dbt_num = i;
                return;
        }
-       PARA_WARNING_LOG("%s", "falling back to the random dbtool\n");
+       PARA_WARNING_LOG("%s", "falling back to the random selector\n");
 random:
        mmd->dbt_num = 0;
        dblist[0].init(&dblist[0]); /* always successful */
@@ -381,7 +381,7 @@ static void handle_dbt_change(void)
                return;
        }
        /* init failed */
-       PARA_ERROR_LOG("%s -- switching to the random dbtool\n", PARA_STRERROR(-ret));
+       PARA_ERROR_LOG("%s -- switching to the random selector\n", PARA_STRERROR(-ret));
        dblist[0].init(&dblist[0]);
        mmd->dbt_num = 0;
 }
@@ -395,8 +395,8 @@ static void handle_sighup(void)
        close_log(logfile); /* gets reopened if necessary by parse_config */
        logfile = NULL;
        parse_config(1); /* reopens log */
-       mmd->dbt_change = mmd->dbt_num; /* do not change dbtool */
-       handle_dbt_change(); /* force reloading dbtool */
+       mmd->dbt_change = mmd->dbt_num; /* do not change selector */
+       handle_dbt_change(); /* reload selector */
 }
 
 static void status_refresh(void)
@@ -47,11 +47,11 @@ INIT_SERVER_ERRLISTS;
 /** the configuration of para_server
  *
- * It also contains the options for all database tools and all supported
+ * It also contains the options for all audio file selectors and all supported
  * senders.
 */